@@ -291,6 +291,10 @@ func (e *executor) getPrebuiltImage() (*types.ImageInspect, error) {
 		imageNameFromConfig = common.AppVersion.Variables().ExpandValue(imageNameFromConfig)
 
 		e.Debugln("Pull configured helper_image for predefined container instead of import bundled image", imageNameFromConfig, "...")
+		if !e.Build.IsFeatureFlagOn(common.FFDockerHelperImageV2) {
+			e.Warningln("DEPRECATION: With gitlab-runner 12.0 we will change some tools inside the helper image, please make sure your image is compliant with the new API. https://gitlab.com/gitlab-org/gitlab-runner/issues/4013")
+		}
+
 		return e.getDockerImage(imageNameFromConfig)
 	}
 
@@ -380,17 +384,21 @@ func (e *executor) getLabels(containerType string, otherLabels ...string) map[st
 
 // createCacheVolume returns the id of the created container, or an error
 func (e *executor) createCacheVolume(containerName, containerPath string) (string, error) {
-	// get busybox image
 	cacheImage, err := e.getPrebuiltImage()
 	if err != nil {
 		return "", err
 	}
 
+	cmd := []string{"gitlab-runner-helper", "cache-init", containerPath}
+	// TODO: Remove in 12.0 to start using the command from `gitlab-runner-helper`
+	if e.checkOutdatedHelperImage() {
+		e.Debugln(common.FFDockerHelperImageV2, "is not set, falling back to old command")
+		cmd = []string{"gitlab-runner-cache", containerPath}
+	}
+
 	config := &container.Config{
 		Image: cacheImage.ID,
-		Cmd: []string{
-			"gitlab-runner-cache", containerPath,
-		},
+		Cmd:   cmd,
 		Volumes: map[string]struct{}{
 			containerPath: {},
 		},
@@ -1299,8 +1307,15 @@ func (e *executor) runServiceHealthCheckContainer(service *types.Container, time
 
 	containerName := service.Names[0] + "-wait-for-service"
 
+	cmd := []string{"gitlab-runner-helper", "health-check"}
+	// TODO: Remove in 12.0 to start using the command from `gitlab-runner-helper`
+	if e.checkOutdatedHelperImage() {
+		e.Debugln(common.FFDockerHelperImageV2, "is not set, falling back to old command")
+		cmd = []string{"gitlab-runner-service"}
+	}
+
 	config := &container.Config{
-		Cmd:    []string{"gitlab-runner-service"},
+		Cmd:    cmd,
 		Image:  waitImage.ID,
 		Labels: e.getLabels("wait", "wait="+service.ID),
 	}
@@ -1399,3 +1414,7 @@ func (e *executor) readContainerLogs(containerID string) string {
 	containerLog := containerBuffer.String()
 	return strings.TrimSpace(containerLog)
 }
+
+func (e *executor) checkOutdatedHelperImage() bool {
+	return !e.Build.IsFeatureFlagOn(common.FFDockerHelperImageV2) && e.Config.Docker.HelperImage != ""
+}
